
'use strict';

/* Dependencies */
const debug = require('debug')('actjs-log')
  , winston = require('winston');

/**
 * @class {Log}
 */
class Log {
  /**
   * @return {String}
   */
  get code() {
    return 'log';
  }

  /**
   * @return {Object}
   */
  get constants() {
    return {
      config: ['log.code', 'log.defaults', 'config.load'],
      logger: ['log.config', Log.logger]
    };
  }

  /**
   * @return {Object}
   */
  get defaults() {
    return {
      winston: {
        exitOnError: false,
        level: 'info'
      },
      console: {
        level: 'debug'
      }
    };
  }

  /**
   * @return {Array}
   */
  get depends() {
    return ['config'];
  }

  /**
   * @return {Array}
   */
  get middleware() {
    return ['log.logger', Log.middleware];
  }

  /**
   * [logger description]
   * @param  {Object} config [description]
   * @return {Object}        [description]
   */
  static logger(config) {
    /* @type {Object} */
    const logger = new winston.Logger(config.winston);

    /* Add the console log transport */
    logger.add(winston.transports.Console, config.console);

    /* Return the logger instance */
    return logger;
  }

  /**
   * [middleware description]
   * @param  {Winston} logger
   */
  static middleware(logger, next) {
    logger.debug('Initiating Log service');
    return next();
  }
}

/* Expose `Log` */
module.exports = Log;
